"use strict";

const { images_url } = require("../../../../../admin-frontend/src/constants");
const { getArticleBody } = require("../../../lib/article-utils");

class SoftwareArticle {
    constructor(props) {
        this.props = props;
    }

    render() {
        const { title, body, subtitle, images, details = [] } = this.props;

        return {
            tag: "article",
            class: "software-article",
            typeof: "SoftwareApplication",
            additionalType: "Article",
            contents: [
                {
                    tag: "h2",
                    class: "software-title",
                    contents: title,
                    property: "name",
                },
                {
                    tag: "div", class: "software-image",
                    contents: [
                        {
                            tag: "img", src: `${images_url}/${images[0]}`
                        }
                    ]
                },
                {
                    tag: "h3",
                    class: "software-subtitle",
                    contents: subtitle,
                    property: "alternativeHeadline",
                },
                {
                    tag: "div",
                    class: "software-description",
                    contents: getArticleBody(body),
                    property: "description",
                },
                details.length > 0 && {
                    tag: "div",
                    class: "article-details",
                    contents: [
                        {
                            tag: "h2",
                            contents: "Details",
                        },
                        {
                            tag: "ul",
                            class: "details-list",
                            contents: details.map(detail => {
                                return {
                                    tag: "li",
                                    class: "detail",
                                    contents: [
                                        { tag: "label", contents: detail.label },
                                        {
                                            tag: "div",
                                            class: "detail-value",
                                            contents: detail.value
                                        },
                                    ],
                                };
                            }),
                        },
                    ],
                },
            ],
        };
    }
}

module.exports = SoftwareArticle;